#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2019-2025 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

from ._decorators import Decorators
from ._federation import FbanAsync, FbanSync
from ._fonts import FontsAsync, FontsSync
from ._images import ImagesAsync, ImagesSync
from ._moderator import ModeratorAsync, ModeratorSync
from ._openai import WhisperAsync, WhisperSync
from ._thinking import WhatAsync, WhatSync

__all__ = [
  "WhisperAsync",
  "WhisperSync",
  "ImagesAsync",
  "ImagesSync",
  "WhatAsync",
  "WhatSync",
  "FbanAsync",
  "FbanSync",
  "ModeratorAsync",
  "ModeratorSync",
  "FontsAsync",
  "FontsSync",
  "Decorators"
]



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2019-2025 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

import os

from ._asynchisded import RyzenthXAsync
from ._synchisded import RyzenthXSync
from .helper import Decorators


class ApiKeyFrom:
    def __init__(self, api_key: str = None, is_free_from_ryzenth=False):
        if api_key is Ellipsis:
            is_free_from_ryzenth = True
            api_key = None

        if not api_key:
            api_key = os.environ.get("RYZENTH_API_KEY")

        if not api_key:
            api_key = "akeno_UKQEQMt991kh2Ehh7JqJYKapx8CCyeC" if is_free_from_ryzenth else None

        self.api_key = api_key
        self.aio = RyzenthXAsync(api_key)
        self._sync = RyzenthXSync(api_key)

    def something(self):
        pass

class UrHellFrom:
    def __init__(self, name: str, only_author=False):
        self.decorators = Decorators(ApiKeyFrom)
        self.ai = self.decorators.send_ai(name=name, only_author=only_author)

    def something(self):
        pass



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2019-2025 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

import logging

import httpx

from .._errors import WhatFuckError

LOGS = logging.getLogger("[Ryzenth]")

class FbanSync:
    def __init__(self, parent):
        self.parent = parent

    def newfed(self, name: str , owner: int, dot_access=False):
        url = f"{self.parent.base_url}/v2/federation/newfed"
        try:
            response = httpx.post(
                url,
                json={"name": name, "owner": owner},
                headers=self.parent.headers,
                timeout=self.parent.timeout
            )
            response.raise_for_status()
            return self.parent.obj(response.json() or {}) if dot_access else response.json()
        except httpx.HTTPError as e:
            LOGS.error(f"[SYNC] Error fetching from newfed {e}")
            raise WhatFuckError("[SYNC] Error fetching from newfed") from e

    def subfed(self, parent_uuid: str, child_uuid: str, dot_access=False):
        url = f"{self.parent.base_url}/v2/federation/subfed"
        try:
            response = httpx.post(
                url,
                json={"parent_uuid": parent_uuid, "child_uuid": child_uuid},
                headers=self.parent.headers,
                timeout=self.parent.timeout
            )
            response.raise_for_status()
            return self.parent.obj(response.json() or {}) if dot_access else response.json()
        except httpx.HTTPError as e:
            LOGS.error(f"[SYNC] Error fetching from subfed {e}")
            raise WhatFuckError("[SYNC] Error fetching from subfed") from e

    def getfed(self, uuid: str, dot_access=False):
        url = f"{self.parent.base_url}/v2/federation/getfed/{uuid}"
        try:
            response = httpx.get(
                url,
                headers=self.parent.headers,
                timeout=self.parent.timeout
            )
            response.raise_for_status()
            return self.parent.obj(response.json() or {}) if dot_access else response.json()
        except httpx.HTTPError as e:
            LOGS.error(f"[SYNC] Error fetching from getfed {e}")
            raise WhatFuckError("[SYNC] Error fetching from getfed") from e

    def unban(self, name: str, user_id: int, dot_access=False):
        url = f"{self.parent.base_url}/v2/federation/unban"
        try:
            response = httpx.post(
                url,
                json={"name": name, "user_id": user_id},
                headers=self.parent.headers,
                timeout=self.parent.timeout
            )
            response.raise_for_status()
            return self.parent.obj(response.json() or {}) if dot_access else response.json()
        except httpx.HTTPError as e:
            LOGS.error(f"[SYNC] Error fetching from unban {e}")
            raise WhatFuckError("[SYNC] Error fetching from unban") from e

    def ban(self, federation_uuid: str, user_id: int, dot_access=False):
        url = f"{self.parent.base_url}/v2/federation/ban"
        try:
            response = httpx.post(
                url,
                json={"federation_uuid": federation_uuid, "user_id": user_id},
                headers=self.parent.headers,
                timeout=self.parent.timeout
            )
            response.raise_for_status()
            return self.parent.obj(response.json() or {}) if dot_access else response.json()
        except httpx.HTTPError as e:
            LOGS.error(f"[SYNC] Error fetching from unban {e}")
            raise WhatFuckError("[SYNC] Error fetching from unban") from e

    def ban_check(self, federation_uuid: str, user_id: int, dot_access=False):
        url = f"{self.parent.base_url}/v2/federation/ban-check"
        try:
            response = httpx.post(
                url,
                json={"federation_uuid": federation_uuid, "user_id": user_id},
                headers=self.parent.headers,
                timeout=self.parent.timeout
            )
            response.raise_for_status()
            return self.parent.obj(response.json() or {}) if dot_access else response.json()
        except httpx.HTTPError as e:
            LOGS.error(f"[SYNC] Error fetching from ban-check {e}")
            raise WhatFuckError("[SYNC] Error fetching from ban-check") from e

    def fedstats(self, uuid: str, dot_access=False):
        url = f"{self.parent.base_url}/v2/federation/fedstats"
        try:
            response = httpx.get(
                url,
                params={"uuid": uuid},
                headers=self.parent.headers,
                timeout=self.parent.timeout
            )
            response.raise_for_status()
            return self.parent.obj(response.json() or {}) if dot_access else response.json()
        except httpx.HTTPError as e:
            LOGS.error(f"[SYNC] Error fetching from fedstats {e}")
            raise WhatFuckError("[SYNC] Error fetching from fedstats") from e

    def unsubfed(self, parent_uuid: str, child_uuid: str, dot_access=False):
        url = f"{self.parent.base_url}/v2/federation/unsubfed"
        try:
            response = httpx.post(
                url,
                json={"parent_uuid": parent_uuid, "child_uuid": child_uuid},
                headers=self.parent.headers,
                timeout=self.parent.timeout
            )
            response.raise_for_status()
            return self.parent.obj(response.json() or {}) if dot_access else response.json()
        except httpx.HTTPError as e:
            LOGS.error(f"[SYNC] Error fetching from unsubfed {e}")
            raise WhatFuckError("[SYNC] Error fetching from unsubfed") from e

    def renamefed(self, federation_uuid: str, new_name: str, dot_access=False):
        url = f"{self.parent.base_url}/v2/federation/renamefed"
        try:
            response = httpx.post(
                url,
                json={"federation_uuid": federation_uuid, "new_name": new_name},
                headers=self.parent.headers,
                timeout=self.parent.timeout
            )
            response.raise_for_status()
            return self.parent.obj(response.json() or {}) if dot_access else response.json()
        except httpx.HTTPError as e:
            LOGS.error(f"[SYNC] Error fetching from renamefed {e}")
            raise WhatFuckError("[SYNC] Error fetching from renamefed") from e

class FbanAsync:
    def __init__(self, parent):
        self.parent = parent

    async def newfed(self, name: str , owner: int, dot_access=False):
        url = f"{self.parent.base_url}/v2/federation/newfed"
        async with httpx.AsyncClient() as client:
            try:
                response = await client.post(
                    url,
                    json={"name": name, "owner": owner},
                    headers=self.parent.headers,
                    timeout=self.parent.timeout
                )
                response.raise_for_status()
                return self.parent.obj(response.json() or {}) if dot_access else response.json()
            except httpx.HTTPError as e:
                LOGS.error(f"[ASYNC] Error: {str(e)}")
                raise WhatFuckError("[ASYNC] Error fetching") from e

    async def subfed(self, parent_uuid: str, child_uuid: str, dot_access=False):
        url = f"{self.parent.base_url}/v2/federation/subfed"
        async with httpx.AsyncClient() as client:
            try:
                response = await client.post(
                    url,
                    json={"parent_uuid": parent_uuid, "child_uuid": child_uuid},
                    headers=self.parent.headers,
                    timeout=self.parent.timeout
                )
                response.raise_for_status()
                return self.parent.obj(response.json() or {}) if dot_access else response.json()
            except httpx.HTTPError as e:
                LOGS.error(f"[ASYNC] Error: {str(e)}")
                raise WhatFuckError("[ASYNC] Error fetching") from e

    async def getfed(self, uuid: str, dot_access=False):
        url = f"{self.parent.base_url}/v2/federation/getfed/{uuid}"
        async with httpx.AsyncClient() as client:
            try:
                response = await client.get(url, headers=self.parent.headers, timeout=self.parent.timeout)
                response.raise_for_status()
                return self.parent.obj(response.json() or {}) if dot_access else response.json()
            except httpx.HTTPError as e:
                LOGS.error(f"[ASYNC] Error: {str(e)}")
                raise WhatFuckError("[ASYNC] Error fetching") from e

    async def unban(self, name: str, user_id: int, dot_access=False):
        url = f"{self.parent.base_url}/v2/federation/unban"
        async with httpx.AsyncClient() as client:
            try:
                response = await client.post(
                    url,
                    json={"name": name, "user_id": user_id},
                    headers=self.parent.headers,
                    timeout=self.parent.timeout
                )
                response.raise_for_status()
                return self.parent.obj(response.json() or {}) if dot_access else response.json()
            except httpx.HTTPError as e:
                LOGS.error(f"[ASYNC] Error: {str(e)}")
                raise WhatFuckError("[ASYNC] Error fetching") from e

    async def ban(self, federation_uuid: str, user_id: int, dot_access=False):
        url = f"{self.parent.base_url}/v2/federation/ban"
        async with httpx.AsyncClient() as client:
            try:
                response = await client.post(
                    url,
                    json={"federation_uuid": federation_uuid, "user_id": user_id},
                    headers=self.parent.headers,
                    timeout=self.parent.timeout
                )
                response.raise_for_status()
                return self.parent.obj(response.json() or {}) if dot_access else response.json()
            except httpx.HTTPError as e:
                LOGS.error(f"[ASYNC] Error: {str(e)}")
                raise WhatFuckError("[ASYNC] Error fetching") from e

    async def ban_check(self, federation_uuid: str, user_id: int, dot_access=False):
        url = f"{self.parent.base_url}/v2/federation/ban-check"
        async with httpx.AsyncClient() as client:
            try:
                response = await client.post(
                    url,
                    json={"federation_uuid": federation_uuid, "user_id": user_id},
                    headers=self.parent.headers,
                    timeout=self.parent.timeout
                )
                response.raise_for_status()
                return self.parent.obj(response.json() or {}) if dot_access else response.json()
            except httpx.HTTPError as e:
                LOGS.error(f"[ASYNC] Error: {str(e)}")
                raise WhatFuckError("[ASYNC] Error fetching") from e

    async def fedstats(self, uuid: str, dot_access=False):
        url = f"{self.parent.base_url}/v2/federation/fedstats"
        async with httpx.AsyncClient() as client:
            try:
                response = await client.get(
                    url,
                    params={"uuid": uuid},
                    headers=self.parent.headers,
                    timeout=self.parent.timeout
                )
                response.raise_for_status()
                return self.parent.obj(response.json() or {}) if dot_access else response.json()
            except httpx.HTTPError as e:
                LOGS.error(f"[ASYNC] Error: {str(e)}")
                raise WhatFuckError("[ASYNC] Error fetching") from e

    async def unsubfed(self, parent_uuid: str, child_uuid: str, dot_access=False):
        url = f"{self.parent.base_url}/v2/federation/unsubfed"
        async with httpx.AsyncClient() as client:
            try:
                response = await client.post(
                    url,
                    json={"parent_uuid": parent_uuid, "child_uuid": child_uuid},
                    headers=self.parent.headers,
                    timeout=self.parent.timeout
                )
                response.raise_for_status()
                return self.parent.obj(response.json() or {}) if dot_access else response.json()
            except httpx.HTTPError as e:
                LOGS.error(f"[ASYNC] Error: {str(e)}")
                raise WhatFuckError("[ASYNC] Error fetching") from e

    async def renamefed(self, federation_uuid: str, new_name: str, dot_access=False):
        url = f"{self.parent.base_url}/v2/federation/renamefed"
        async with httpx.AsyncClient() as client:
            try:
                response = await client.post(
                    url,
                    json={"federation_uuid": federation_uuid, "new_name": new_name},
                    headers=self.parent.headers,
                    timeout=self.parent.timeout
                )
                response.raise_for_status()
                return self.parent.obj(response.json() or {}) if dot_access else response.json()
            except httpx.HTTPError as e:
                LOGS.error(f"[ASYNC] Error: {str(e)}")
                raise WhatFuckError("[ASYNC] Error fetching") from e



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2019-2025 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

import logging

import httpx

from .._errors import WhatFuckError
from ..types import QueryParameter

LOGS = logging.getLogger("[Ryzenth]")

class WhatAsync:
    def __init__(self, parent):
        self.parent = parent

    async def think(self, params: QueryParameter, dot_access=False):
        url = f"{self.parent.base_url}/v1/ai/deepseek/deepseek-r1-distill-qwen-32b"
        async with httpx.AsyncClient() as client:
            try:
                response = await client.get(
                    url,
                    params=params.dict(),
                    headers=self.parent.headers,
                    timeout=self.parent.timeout
                )
                response.raise_for_status()
                return self.parent.obj(response.json() or {}) if dot_access else response.json()
            except httpx.HTTPError as e:
                LOGS.error(f"[ASYNC] Error: {str(e)}")
                raise WhatFuckError("[ASYNC] Error fetching") from e

class WhatSync:
    def __init__(self, parent):
        self.parent = parent

    def think(self, params: QueryParameter, dot_access=False):
        url = f"{self.parent.base_url}/v1/ai/deepseek/deepseek-r1-distill-qwen-32b"
        try:
            response = httpx.get(
                url,
                params=params.dict(),
                headers=self.parent.headers,
                timeout=self.parent.timeout
            )
            response.raise_for_status()
            return self.parent.obj(response.json() or {}) if dot_access else response.json()
        except httpx.HTTPError as e:
            LOGS.error(f"[SYNC] Error fetching from deepseek {e}")
            raise WhatFuckError("[SYNC] Error fetching from deepseek") from e



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2019-2025 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

from functools import wraps

from ..types import QueryParameter


class Decorators:
    def __init__(self, class_func):
        self._clients_ai = class_func(..., is_free_from_ryzenth=True)

    def send_ai(self, name: str, only_author=False):
        def decorator(func):
            @wraps(func)
            async def wrapper(client, message, *args, **kwargs):
                if only_author and message.from_user.id != client.me.id:
                    return await message.reply_text(
                        "Only Developer can use this command.", **kwargs
                        )
                query = message.text.split(maxsplit=1)[1] if len(message.text.split()) > 1 else ""
                if not query:
                    return await message.reply_text(
                        "Please provide a query after the command.", **kwargs
                    )
                result = await self._clients_ai.aio.send_message(
                    name, QueryParameter(query=query), dot_access=True
                )
                await message.reply_text(result.results, **kwargs)
                return await func(client, message, query, *args, **kwargs)
            return wrapper
        return decorator



import os
import re

import setuptools


def read(fname, version=False):
    text = open(os.path.join(os.path.dirname(__file__), fname), encoding="utf8").read()
    return re.search(r'__version__ = "(.*?)"', text)[1] if version else text

setuptools.setup(
    name="Ryzenth",
    packages=setuptools.find_packages(),
    version=read("Ryzenth/__version__.py", version=True),
    license="MIT",
    description="Ryzenth Python Wrapper For Perfomance",
    long_description=read("README.md"),
    long_description_content_type="text/markdown",
    author="TeamKillerX",
    project_urls={
        "Source": "https://github.com/TeamKillerX/Ryzenth/",
        "Issues": "https://github.com/TeamKillerX/Ryzenth/issues",
    },
    keywords=[
        "API",
        "Ryzenth",
    ],
    install_requires=[
        "requests",
        "pydantic",
        "typing",
        "aiohttp",
        "httpx[http2]",
        "bs4",
        "python-box",
    ],
    extras_require={
        "fast": [
            "aiohttp",
            "wget",
            "requests",
            "httpx[http2]",
            "python-box",
            "pydantic",
            "bs4",
            "typing",
        ]
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Intended Audience :: Developers",
        "Natural Language :: English",
    ],
    python_requires="~=3.7",
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2019-2025 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

import logging

import httpx
from box import Box

from ._errors import WhatFuckError
from .helper import (
    FbanAsync,
    FontsAsync,
    ImagesAsync,
    ModeratorAsync,
    WhatAsync,
    WhisperAsync,
)
from .types import DownloaderBy, QueryParameter

LOGS = logging.getLogger("[Ryzenth] async")

class RyzenthXAsync:
    def __init__(self, api_key: str, base_url: str = "https://randydev-ryu-js.hf.space/api"):
        self.api_key = api_key
        self.base_url = base_url.rstrip("/")
        self.headers = {"x-api-key": self.api_key}
        self.timeout = 10
        self.params = {}
        self.images = ImagesAsync(self)
        self.what = WhatAsync(self)
        self.openai_audio = WhisperAsync(self)
        self.federation = FbanAsync(self)
        self.moderator = ModeratorAsync(self)
        self.fonts = FontsAsync(self)
        self.obj = Box

    async def send_downloader(
        self,
        switch_name: str = None,
        params: DownloaderBy = None,
        list_key=False,
        dot_access=False
    ):
        dl_dict = {
            "teraboxv4": "terabox-v4",
            "twitterv3": "twitter-v3",
            "xnxxinfov2": "xnxx-info-v2",
            "instagramv4": "instagram-v4",
            "instagramv3": "instagram-v3",
            "instagramv2": "instagram-v2",
            "instagram": "instagram",
            "twitter": "twitter",
            "tiktok": "tiktok",
            "tiktokv2": "tiktok-v2",
            "facebook": "fb",
            "snapsave": "snapsave",
            "savefrom": "savefrom"
        }
        if list_key:
            return list(dl_dict.keys())

        if not switch_name:
            raise ValueError("`switch_name` is required. Use `list_key=True` to see all valid options.")

        model_name = dl_dict.get(switch_name)
        if not model_name:
            raise ValueError(f"Invalid switch_name: {switch_name}")

        async with httpx.AsyncClient() as client:
            try:
                response = await client.get(
                    f"{self.base_url}/v1/dl/{model_name}",
                    params=params.dict(),
                    headers=self.headers,
                    timeout=self.timeout
                )
                response.raise_for_status()
                return self.obj(response.json() or {}) if dot_access else response.json()
            except httpx.HTTPError as e:
                LOGS.error(f"[ASYNC] Error: {str(e)}")
                raise WhatFuckError("[ASYNC] Error fetching") from e

    async def send_message(
        self,
        model: str = None,
        params: QueryParameter = None,
        list_key=False,
        dot_access=False
    ):
        model_dict = {
            "hybrid": "AkenoX-1.9-Hybrid",
            "hybrid-english": "AkenoX-1.9-Hybrid-Englsih",
            "melayu": "lu-melayu",
            "nocodefou": "nocodefou",
            "mia": "mia-khalifah",
            "curlmcode": "curl-command-code",
            "quotessad": "quotes-sad",
            "quoteslucu": "quotes-lucu",
            "lirikend": "lirik-end",
            "alsholawat": "al-sholawat"
        }
        if list_key:
            return list(model_dict.keys())

        if not model:
            raise ValueError("`model` is required. Use `list_key=True` to see all valid options.")

        model_param = model_dict.get(model)
        if not model_param:
            raise ValueError(f"Invalid model name: {model}")

        async with httpx.AsyncClient() as client:
            try:
                response = await client.get(
                    f"{self.base_url}/v1/ai/akenox/{model_param}",
                    params=params.dict(),
                    headers=self.headers,
                    timeout=self.timeout
                )
                response.raise_for_status()
                return self.obj(response.json() or {}) if dot_access else response.json()
            except httpx.HTTPError as e:
                LOGS.error(f"[ASYNC] Error: {str(e)}")
                raise WhatFuckError("[ASYNC] Error fetching") from e
